@@ -2,6 +2,6 @@ import os
 
 IFTTT_USERNAME = os.getenv('IFTTT_USERNAME')
 IFTTT_PASSWORD = os.getenv('IFTTT_PASSWORD')
-IFTTT_IMAP_SERVER = os.getenv('IFTTT_IMAP_SERVER')
-IFTTT_IMAP_PORT = os.getenv('IFTTT_IMAP_PORT', 993)
+IFTTT_SERVER = os.getenv('IFTTT_IMAP_SERVER')
+IFTTT_PORT = os.getenv('IFTTT_IMAP_PORT', 993)
 IFTTT_DELIM = os.getenv('IFTTT_DELIM', '\|\|\|\|\|')
\ No newline at end of file
